PyBaccarat: tests.test_ties.TestTies Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | List of all members
tests.test_ties.TestTies Class Reference
Inheritance diagram for tests.test_ties.TestTies:

## Public Member Functions
def | test_constructor (self)
def | test_post_tt (self)
def | test_basics (self)
| TBD.
def | test_first_tie (self)
def | test_triple_tie (self)
| TBD.
def | test_basics2 (self)
def | test_extreme_slide (self)
def | test_9116_slide (self)
def | test_91176_slide (self)
def | test_same_long_strings (self)
def | test_getarray (self)
def | test_getseq (self)
def | test_mark (self)
def | test_get_cs_mark (self)
def | test_get_peek_B_array (self)
def | test_print_lines (self)
def | test_inherit (self)

## Detailed Description

    Unit test for the Ties class.

## Member Function Documentation

## ◆ test_9116_slide()

def tests.test_ties.TestTies.test_9116_slide | ( |  | self | ) |

    test a specific slide condition, 9116

## ◆ test_91176_slide()

def tests.test_ties.TestTies.test_91176_slide | ( |  | self | ) |

    test a specific slide condition, 91176

## ◆ test_constructor()

def tests.test_ties.TestTies.test_constructor | ( |  | self | ) |

    test card construction

## ◆ test_extreme_slide()

def tests.test_ties.TestTies.test_extreme_slide | ( |  | self | ) |

    test the condition of slide go too far to the right

## ◆ test_get_cs_mark()

def tests.test_ties.TestTies.test_get_cs_mark | ( |  | self | ) |

    test get_cs_mark() method

## ◆ test_getarray()

def tests.test_ties.TestTies.test_getarray | ( |  | self | ) |

    test get_rank method

## ◆ test_getseq()

def tests.test_ties.TestTies.test_getseq | ( |  | self | ) |

    test getseq() method

## ◆ test_inherit()

def tests.test_ties.TestTies.test_inherit | ( |  | self | ) |

    inheritted things from object:

    c = playingcards.Card(5,'s')
    dir(c)
    ['__delattr__', '__getattribute__', '__setattr__', '__new__',
    '__dict__', '__dir__', '__format__', '__init_subclass__',
    '__subclasshook__', '__reduce__', '__reduce_ex__', '__weakref__']

    @todo inherit tests

## ◆ test_mark()

def tests.test_ties.TestTies.test_mark | ( |  | self | ) |

    test mark() method

## ◆ test_same_long_strings()

def tests.test_ties.TestTies.test_same_long_strings | ( |  | self | ) |

    test the condition of 2 same type long strings in parallel and
    a possible collision.

The documentation for this class was generated from the following file:

- tests/test_ties.py